@@ -38,7 +38,7 @@
 //!
 //! First add this to your `Cargo.toml` file:
 //! ```toml
-//! skytable = "0.6.0"
+//! skytable = "0.6.1"
 //! ```
 //! Now open up your `src/main.rs` file and establish a connection to the server while also adding some
 //! imports:
@@ -125,7 +125,7 @@
 //!
 //! If you need to use an `async` API, just change your import to:
 //! ```toml
-//! skytable = { version = "0.6.0", features=["async"], default-features=false }
+//! skytable = { version = "0.6.1", features=["async"], default-features=false }
 //! ```
 //! You can now establish a connection by using `skytable::AsyncConnection::new()`, adding `.await`s wherever
 //! necessary. Do note that you'll the [Tokio runtime](https://tokio.rs).
@@ -135,7 +135,7 @@
 //! With this client driver, it is possible to use both sync and `async` APIs **at the same time**. To do
 //! this, simply change your import to:
 //! ```toml
-//! skytable = { version="0.6.0", features=["sync", "async"] }
+//! skytable = { version="0.6.1", features=["sync", "async"] }
 //! ```
 //!
 //! ## TLS
@@ -144,13 +144,13 @@
 //!
 //! ### Using TLS with sync interfaces
 //! ```toml
-//! skytable = { version="0.6.0", features=["sync","ssl"] }
+//! skytable = { version="0.6.1", features=["sync","ssl"] }
 //! ```
 //! You can now use the async [TlsConnection](`sync::TlsConnection`) object.
 //!
 //! ### Using TLS with async interfaces
 //! ```toml
-//! skytable = { version="0.6.0", features=["async","aio-ssl"], default-features=false }
+//! skytable = { version="0.6.1", features=["async","aio-ssl"], default-features=false }
 //! ```
 //! You can now use the async [TlsConnection](`aio::TlsConnection`) object.
 //!
@@ -425,9 +425,6 @@ impl Query {
         self
     }
     pub(in crate) fn _push_arg(&mut self, arg: Vec<u8>) {
-        if arg.is_empty() {
-            panic!("Argument cannot be empty")
-        }
         // A data element will look like:
         // `<bytes_in_next_line>\n<data>`
         let bytes_in_next_line = arg.len().to_string().into_bytes();
@@ -447,10 +444,6 @@ impl Query {
     /// ## Panics
     /// This method will panic if the passed `arg` is empty
     pub fn push(&mut self, arg: impl IntoSkyhashAction) {
-        assert!(
-            arg.incr_len_by() != 0,
-            "An argument passed to a query cannot be empty!"
-        );
         arg.push_into_query(self);
     }
     pub(in crate) fn _push_alt_iter<T, U>(
